#define PROGNAME "siggy"
#define DATA_FOLDER "."PROGNAME
#define DB_FILENAME PROGNAME".sqlite"
#define CONFIG_FILENAME PROGNAME".conf"
#define I18N_FILES_PATH "/usr/share/"PROGNAME

#define ORGANIZATION_NAME "Igalia"

#define ACTIVE_ACCOUNT_KEY "activeAccount"
